@@ -5,7 +5,7 @@ use warnings;
 use parent qw(Class::Accessor::Fast);
 use Carp;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 __PACKAGE__->mk_accessors(qw/registered_classes autoloader_rules objects/);
 
@@ -84,6 +84,12 @@ sub instance {
     return $INSTANCES{$class} ||= $class->new;
 }
 
+sub has_instance {
+    my $class = shift;
+    $class = ref $class || $class;
+    return $INSTANCES{$class};
+};
+
 sub new {
     $_[0]->SUPER::new( +{
         registered_classes => +{},
